resmush: Optimize and Compress Image Files with 'reSmush.it'
Source:R/resmush-package.R
resmush-package.RdOptimize and compress local and online image files with the 'reSmush.it' 'API' https://resmush.it/api/. Process individual files or entire directories. The 'API' is free for personal use, accepts files smaller than 5 'MB' and supports 'PNG', 'JPEG', 'GIF', 'BMP' and 'TIFF' files.
See also
resmush_file()optimizes local image files.resmush_dir()optimizes image files in directories.resmush_url()optimizes online image files.The package website provides articles and reference documentation.
The source code is available on GitHub.
Report bugs in the issue tracker.
Author
Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]
Authors:
Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]