| resmush-package | R Documentation |
Optimize and compress local and online image files with the 'reSmush.it' 'API' https://resmush.it/api/. Process individual files or entire directories. The 'API' is free for personal use, accepts files smaller than 5 'MB' and supports 'PNG', 'JPEG', 'GIF', 'BMP' and 'TIFF' files.
Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]
Authors:
Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]
resmush_file() optimizes local image files.
resmush_dir() optimizes image files in directories.
resmush_url() optimizes online image files.
The package website provides articles and reference documentation.
The source code is available on GitHub.
Report bugs in the issue tracker.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.